---
title: <span class="badge object-type-scalar"></span> MilliWatt
---
# <span class="badge object-type-scalar"></span> MilliWatt

Energy: Milliwatt (mW)

## Definition

```python
# Energy: Milliwatt (mW)
MilliWatt: typing.Literal["mwatt"] = "mwatt"
```
